// generated from rosidl_adapter/resource/srv.idl.em
// with input from nav_msgs/srv/LoadMap.srv
// generated code does not contain a copyright notice

#include "nav_msgs/msg/OccupancyGrid.idl"

module nav_msgs {
  module srv {
    @verbatim (language="comment", text=
      "URL of map resource" "\n"
      "Can be an absolute path to a file: file:///path/to/maps/floor1.yaml" "\n"
      "Or, relative to a ROS package: package://my_ros_package/maps/floor2.yaml")
    struct LoadMap_Request {
      string map_url;
    };
    module LoadMap_Response_Constants {
      const uint8 RESULT_SUCCESS = 0;
      const uint8 RESULT_MAP_DOES_NOT_EXIST = 1;
      const uint8 RESULT_INVALID_MAP_DATA = 2;
      const uint8 RESULT_INVALID_MAP_METADATA = 3;
      const uint8 RESULT_UNDEFINED_FAILURE = 255;
    };
    @verbatim (language="comment", text=
      "Result code defintions")
    struct LoadMap_Response {
      @verbatim (language="comment", text=
        "Returned map is only valid if result equals RESULT_SUCCESS")
      nav_msgs::msg::OccupancyGrid map;

      uint8 result;
    };
  };
};
